@@ -12,11 +12,12 @@ from ...process.braggdiskdetection import get_bragg_vector_map
 from skimage.transform import radon
 from ...process.latticevectors import get_radon_scores, get_lattice_directions_from_scores, get_lattice_vector_lengths, generate_lattice
 from scipy.ndimage.filters import gaussian_filter
-from ...file.datastructure import PointList 
+from ...file.datastructure import PointList
 from .cmaptopg import cmapToColormap
 from matplotlib.cm import get_cmap
 from ...process.latticevectors import get_strain_from_reference_region, fit_lattice_vectors_all_DPs
-from ...file.io import save, append, is_py4DSTEM_file, read
+from ...file.io import read
+from ...file.io.native import save, append, is_py4DSTEM_file
 from ...file.datastructure import DiffractionSlice, RealSlice
 from .ImageViewMasked import ImageViewAlpha
 
@@ -207,15 +208,15 @@ class VacuumDCTab(QtWidgets.QWidget):
 			self.lineEdit_LoadFile.setText(fname)
 			# check the load mode and load file:
 			if self.loadRadioAuto.isChecked():
-				self.main_window.strain_window.vac_datacube = read(fname)
+				self.main_window.strain_window.vac_datacube,_ = read(fname)
 				if binning > 1:
 					self.main_window.strain_window.vac_datacube.bin_data_diffraction(binning)
 			elif self.loadRadioMMAP.isChecked():
-				self.main_window.strain_window.vac_datacube = read(fname, load='dmmmap')
+				self.main_window.strain_window.vac_datacube,_ = read(fname, load='dmmmap')
 				if binning > 1:
 					self.main_window.strain_window.vac_datacube.bin_data_mmap(binning)
 			elif self.loadRadioGatan.isChecked():
-				self.main_window.strain_window.vac_datacube = read(fname, load='gatan_bin')
+				self.main_window.strain_window.vac_datacube,_ = read(fname, load='gatan_bin')
 				if binning > 1:
 					self.main_window.strain_window.vac_datacube.bin_data_mmap(binning)
 
@@ -1412,11 +1413,11 @@ class StrainMapTab(QtWidgets.QWidget):
 			try:
 				# file was chosen
 				if is_py4DSTEM_file(f[0]):
-					append([sw.ProbeKernelDS,sw.braggdisks,sw.braggdisks_corrected,
-						sw.BVMDS,sw.lattice_vectors,sw.uv_map, sw.strain_map],f[0])
+					append(f[0],[sw.ProbeKernelDS,sw.braggdisks,sw.braggdisks_corrected,
+						sw.BVMDS,sw.lattice_vectors,sw.uv_map, sw.strain_map])
 				else:
-					save([sw.ProbeKernelDS,sw.braggdisks,sw.braggdisks_corrected,
-						sw.BVMDS,sw.lattice_vectors,sw.uv_map, sw.strain_map],f[0])
+					save(f[0],[sw.ProbeKernelDS,sw.braggdisks,sw.braggdisks_corrected,
+						sw.BVMDS,sw.lattice_vectors,sw.uv_map, sw.strain_map])
 			except Exception as exc:
 				print('Failed to save...')
 				print(format(exc))
@@ -1436,11 +1437,11 @@ class StrainMapTab(QtWidgets.QWidget):
 			try:
 				# file was chosen
 				if is_py4DSTEM_file(f[0]):
-					append([self.main_window.datacube,sw.ProbeKernelDS,sw.braggdisks,sw.braggdisks_corrected,
-						sw.BVMDS,sw.lattice_vectors,sw.uv_map, sw.strain_map],f[0])
+					append(f[0],[self.main_window.datacube,sw.ProbeKernelDS,sw.braggdisks,sw.braggdisks_corrected,
+						sw.BVMDS,sw.lattice_vectors,sw.uv_map, sw.strain_map])
 				else:
-					save([self.main_window.datacube,sw.ProbeKernelDS,sw.braggdisks,sw.braggdisks_corrected,
-						sw.BVMDS,sw.lattice_vectors,sw.uv_map, sw.strain_map],f[0])
+					save(f[0],[self.main_window.datacube,sw.ProbeKernelDS,sw.braggdisks,sw.braggdisks_corrected,
+						sw.BVMDS,sw.lattice_vectors,sw.uv_map, sw.strain_map])
 			except Exception as exc:
 				print('Failed to save...')
 				print(format(exc))
